----------------------------------------------------
------------------ AthComboPoints ------------------
----------------------------------------------------
-- Author: Athariel / trysor

-- CHANGE THESE TO REPOSITION THE COMBO POINTS
local anchorPoint = "CENTER";
local relativeTo = UIParent;
local relativePoint = "CENTER";
local posX = 100; -- left to right (0 == left)
local posY = -40; -- top to bottom (0 == top)

----------------------------------------------------
-------------- Combo Point Functions ---------------
----------------------------------------------------
local class = strlower(select(2, UnitClass("Player")));
local classes = {
	["rogue"] = 6,
	["druid"] = 5, 
	["monk"] = 5, -- 4 + 1 (talent)
	["paladin"] = 5, -- 3 + 2
	["priest"] = 5
};


-- don't load rest if not a supported class
if classes[class] == nil then return; end

-- often used functions
local UnitPower = UnitPower;
local UnitPowerMax = UnitPowerMax;

local class_resource = {
	["rogue"] = SPELL_POWER_COMBO_POINTS,
	["druid"] = SPELL_POWER_COMBO_POINTS, 
	["monk"] = SPELL_POWER_CHI,
	["paladin"] = SPELL_POWER_HOLY_POWER,
	["priest"] = SPELL_POWER_SHADOW_ORBS,
};

local resource = class_resource[class];


----------------------------------------------------
------------------- Frame config -------------------
----------------------------------------------------
local frame = CreateFrame("frame", nil, UIParent);
frame:SetFrameStrata("BACKGROUND");
frame:SetHeight(90);
frame:SetWidth(35);
frame:SetPoint(anchorPoint, relativeTo, relativePoint, posX, posY);

----------------------------------------------------
-------------------- CP creation -------------------
----------------------------------------------------
local function createCPs(column)
	local f = CreateFrame("frame", nil, frame);
	for i = 1, classes[class] do
		tinsert(f, CreateFrame("frame", nil, frame));

		local CP = f[i];
		CP:SetHeight(15);
		CP:SetWidth(15);

		CP.Texture = CP:CreateTexture();
		CP.Texture:SetAllPoints(CP);
		CP.Texture:SetTexture("Interface\\ComboFrame\\ComboPoint");
		CP.Texture:SetTexCoord(0,0.375,0,0.8);
		if (column == 0) then CP.Texture:SetVertexColor(0.8, 0.2, 0.2);
		else CP.Texture:SetVertexColor(0.6, 0.2, 1); end

		CP:SetPoint("TOPLEFT", frame, "TOPLEFT", column*20, -(18)*(i-1));
	end
	return f;
end

----------------------------------------------------
--------------------- CP Frame ---------------------
----------------------------------------------------
frame.CP = createCPs(0); -- column 0
frame.CP2 = createCPs(1); -- column 1
local function updateCP()
	local CPs = UnitPower("player", resource);
	local maxComboPoints = UnitPowerMax("player", resource);
	for i = 1, classes[class] do
		frame.CP[i]:Hide();
		if i <= CPs then
			frame.CP[i]:Show();
		end
		
		-- Anticipation
		frame.CP2[i]:Hide();
		if (maxComboPoints > classes[class]) then
			if (maxComboPoints - 3 + i) <= CPs then
				frame.CP2[i]:Show();
			end
		end
	end
end
updateCP();

----------------------------------------------------
------------------ Register Events -----------------
----------------------------------------------------

frame.CP:RegisterUnitEvent("UNIT_POWER", "player");
frame.CP:RegisterEvent("PLAYER_ENTERING_WORLD");
frame.CP:SetScript("OnEvent", updateCP);

